pub struct VersionPluginDependencies {
pub name: String,
pub required: bool,
pub external_url: Option<String>,
pub platform: Platform,
}Fields
name: StringName of the plugin dependency. For non-external dependencies, this should be the Hangar project name
required: boolWhether the dependency is required for the plugin to function
external_url: Option<String>External url to download the dependency from if not a Hangar project, else null
platform: PlatformServer platform