pub struct VersionsRequest {
pub slug: String,
pub pagination: Pagination,
pub include_hidden_channels: Option<bool>,
pub channel: Option<String>,
pub platform: Option<Platform>,
pub platform_version: Option<String>,
}Expand description
Returns all versions of a project. Requires the view_public_info permission in the project or owning organization.
Fields
slug: StringThe slug of the project to return versions for
pagination: PaginationWhether to include hidden-by-default channels in the result, defaults to try
channel: Option<String>A name of a version channel to filter for
platform: Option<Platform>A platform name to filter for
platform_version: Option<String>A platform version to filter for
Implementations
Sourceimpl VersionsRequest
impl VersionsRequest
Sourcepub fn builder() -> VersionsRequestBuilder<((), (), (), (), (), ())>
pub fn builder() -> VersionsRequestBuilder<((), (), (), (), (), ())>
Create a builder for building VersionsRequest.
On the builder, call .slug(...), .pagination(...), .include_hidden_channels(...)(optional), .channel(...)(optional), .platform(...)(optional), .platform_version(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of VersionsRequest.